@@ -54,7 +54,7 @@ ChangesEditorDialog::ChangesEditorDialog(BaseObjectType* baseObject,
                                          const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Dialog(baseObject)
 {
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   xml->get_widget("modified_galleries_expander", modified_galleries_expander);
   xml->get_widget("modified_galleries_treeview", modified_galleries_treeview);
   xml->get_widget("modified_galleries_label", modified_galleries_label);
@@ -185,7 +185,7 @@ void ChangesEditorDialog::update_buttons()
       changes.removed_galleries.size() == 0 &&
       changes.added_galleries.size() == 0 &&
       changes.removed_documents.size() == 0 &&
-      changes.added_documents.size() == 0 && 
+      changes.added_documents.size() == 0 &&
       reverts.empty() == true)
     accept_button->set_sensitive(false);
 }
