@@ -32,6 +32,8 @@ class ChangesEditorDialog: public Gtk::Dialog
 
     Tapioca::SessionChanges get_reverted_changes() const {return reverts;}
     Tapioca::SessionChanges get_changes() const {return changes;}
+    //signals
+    sigc::signal<void, Tapioca::Document*> view_document;
  private:
     Tapioca::Session *session;
     Tapioca::SessionChanges changes;
