@@ -23,22 +23,18 @@
 #include "profile.h"
 using namespace Tapioca;
 
-class ConnectDialog
+class ConnectDialog: public Gtk::Dialog
 {
  public:
-    ConnectDialog(Tapioca::Profile *p, bool modify_username = true);
-    ~ConnectDialog();
+    static ConnectDialog* create(Tapioca::Profile *p, 
+                                 bool modify_username = true);
 
-    void set_parent_window(Gtk::Window &parent);
-
-    int run();
-    void hide();
-
- protected:
+    ConnectDialog(BaseObjectType* baseObject, const Glib::RefPtr<Gtk::Builder>& xml);
+    virtual ~ConnectDialog();
 
  private:
     Tapioca::Profile *profile;
-    Gtk::Dialog* dialog;
+    bool username_locked;
     Gtk::Entry *username_entry;
     Gtk::Entry *password_entry;
     Gtk::Button *accept_button;
@@ -46,6 +42,9 @@ class ConnectDialog
     //callbacks
     void on_username_changed();
     void on_password_changed();
+    void on_dialog_loaded(Tapioca::Profile *p, bool modify_username);
+    void on_response_received(int response);
+
     //helpers
     void update_buttons();
 
