@@ -88,7 +88,7 @@ DocumentDialog::DocumentDialog(BaseObjectType* baseObject,
                                const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Dialog(baseObject)
 {
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
 
   signal_response().connect
     (sigc::mem_fun(*this, &DocumentDialog::on_response_received));
