@@ -43,7 +43,7 @@ GalleryDialog::GalleryDialog(BaseObjectType* baseObject,
   gallery = NULL;
   original = NULL;
   readonly = false;
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
 
   signal_response().connect
     (sigc::mem_fun(*this, &GalleryDialog::on_response_received));
