@@ -1,4 +1,4 @@
-// Copyright (C) 2010 Ben Asselstine
+// Copyright (C) 2010, 2011 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -30,10 +30,13 @@
 namespace Tapioca
 {
 class Document;
-class Gallery: public std::list<Document*>, public Item
+class Gallery: public Item
 {
     public:
 
+        typedef std::list<Document*>::iterator iterator;
+        typedef std::list<Document*>::const_iterator const_iterator;
+
 	//! Copy constructor.
         Gallery(const Gallery& gallery);
 
@@ -51,6 +54,8 @@ class Gallery: public std::list<Document*>, public Item
 
         void set_document_order(Document *document, Document *after);
 
+        void set_private_audience(bool p) {private_audience = p;};
+
         void remove_document(Document *document);
 
         void remove_all_documents();
@@ -65,11 +70,24 @@ class Gallery: public std::list<Document*>, public Item
 
         //Get Methods
 
-        Glib::RefPtr<Gdk::Pixbuf> get_thumbnail_image() const;
-        std::string get_thumbnail_id() const {return document_thumbnail_id;}
+        const std::list<Document*>& get_docs() const {return _docs;}
+        size_t size() const {return _docs.size();}
+        Document* back() {return _docs.back();}
+        void clear() {_docs.clear();}
+
+        const Glib::RefPtr<Gdk::Pixbuf> get_thumbnail_image() const;
+        const std::string& get_thumbnail_id() const {return document_thumbnail_id;}
 
         void export_html_page(std::string export_dir) const;
 
+        bool same_except_for_thumbnail_id(const Gallery& gallery) const;
+
+        bool same_except_for_tags(const Gallery& gallery) const;
+
+        Document* find_by_id(std::string i) const;
+
+        bool get_private_audience() const{return private_audience;}
+
         //operators
         bool operator==(const Gallery &other)
           {
@@ -79,32 +97,57 @@ class Gallery: public std::list<Document*>, public Item
               title == other.title &&
               description == other.description &&
               document_thumbnail_id == other.document_thumbnail_id &&
+              private_audience == other.private_audience &&
               order == other.order &&
               tags == other.tags;
           }
+        static sigc::signal<void> loading;
+        static sigc::signal<void> saving;
     protected:
 
     private:
         std::string document_thumbnail_id;
+        bool private_audience;
 
         std::string get_next_in_order_sequence(std::string seq);
         bool has_order(std::string o) const;
 
         friend class boost::serialization::access;
                              
-        template<class Archive>
-          void serialize(Archive & ar, const unsigned int version)
-            {
+         template<class Archive>
+           void save(Archive & ar, const unsigned int version) const
+             {
               ar & id;
               ar & latitude;
               ar & longitude;
               ar & title;
               ar & description;
               ar & document_thumbnail_id;
+              ar & private_audience;
               ar & order;
               ar & tags;
-              ar & static_cast<std::list<Document*>&>(*this);
-            }
+              ar & _docs;
+              saving();
+             }
+         template<class Archive>
+           void load(Archive & ar, const unsigned int version)
+             {
+              loading();
+              ar & id;
+              ar & latitude;
+              ar & longitude;
+              ar & title;
+              ar & description;
+              ar & document_thumbnail_id;
+              ar & private_audience;
+              ar & order;
+              ar & tags;
+              ar & _docs;
+             }
+         BOOST_SERIALIZATION_SPLIT_MEMBER()
+        std::list<Document*> _docs;
+        void remove(Document *document) {_docs.remove(document);}
+        void push_back(Document *document) {_docs.push_back(document);}
 };
 }
 
