@@ -28,7 +28,7 @@ ProgressDialog::ProgressDialog()
 				    + "/progress-dialog.gtk");
 
     xml->get_widget("dialog", dialog);
-    dialog->set_icon_from_file(Main::get_data_path() + "/icon.png");
+    dialog->set_icon_from_file(Main::get_data_path() + "/tapioca.png");
 
     xml->get_widget("progressbar", progressbar);
     xml->get_widget("label", label);
