@@ -37,7 +37,7 @@ PublishDialog::PublishDialog(BaseObjectType* baseObject,
                              const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Dialog(baseObject)
 {
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   xml->get_widget("changes_label", changes_label);
 }
 
