@@ -36,7 +36,7 @@ QuitDialog::QuitDialog(BaseObjectType* baseObject,
                              const Glib::RefPtr<Gtk::Builder>& xml)
  : Gtk::Dialog(baseObject)
 {
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
 }
 
 void QuitDialog::on_dialog_loaded()
