@@ -704,8 +704,6 @@ SessionConnector::revert_removed_document (ChangedDocument d)
       Gallery *gallery = session->find_by_id (d.first.get_gallery_id ());
       if (gallery)
 	{
-	  printf ("adding doc to gallery `%s'\n",
-		  gallery->get_title ().c_str ());
 	  if (session->find_doc_by_id (d.first.get_id ()) == NULL)
 	    gallery->add_document (new Document (*document));
 	  return true;
@@ -981,7 +979,7 @@ SessionConnector::on_add_gallery_attempted (Glib::RefPtr < Soup::Message >
 				    mem_fun (this,
 					     &SessionConnector::
 					     on_new_gallery_updated_tag),
-				    slot, gallery));
+				    slot, gallery), true);
     }
   else
     slot (gallery);
@@ -1000,13 +998,14 @@ SessionConnector::on_new_gallery_updated_tag (Item * item,
 void
 SessionConnector::update_item_tags (Item * item,
 				    const SessionConnector::
-				    SlotUpdateTags slot)
+				    SlotUpdateTags slot, bool gallery)
 {
 //http://master.atpic.com/tag_insert.php?type=g&refparent=38558&secret=&tags=
   Glib::RefPtr < Soup::Message > msg;
   Glib::ustring url = String::ucompose
-    ("%1/tag_insert.php?type=g&refparent=%2&secret=&tags=",
-     session->get_profile ()->get_url (), item->get_id ());
+    ("%1/tag_insert.php?type=%2&refparent=%3&secret=%4&tags=",
+     session->get_profile ()->get_url (), gallery ? "g" : "p", item->get_id (),
+     gallery ? "" : "0");
   msg = Soup::Message::create ("GET", url);
   //go get our session id.
   int status = web->send_message (msg);
@@ -1035,10 +1034,16 @@ SessionConnector::update_item_tags (Item * item,
 
   std::map < std::string, std::string > formdata;
   formdata["submitted"] = "1";
-  formdata["secret"] = "";
+  if (gallery)
+    formdata["secret"] = "";
+  else
+    formdata["secret"] = "0";
   formdata["sessionid"] = session_id;
   formdata["refparent"] = item->get_id ();
-  formdata["type"] = "g";
+  if (gallery)
+    formdata["type"] = "g";
+  else
+    formdata["type"] = "p";
   formdata["tags"] = item->get_tags_as_string ();
   formdata["submit"] = "Submit";
   msg =
@@ -1059,7 +1064,8 @@ SessionConnector::on_update_tags_attempted (Glib::RefPtr < Soup::Message >
 					    const SessionConnector::
 					    SlotUpdateTags slot)
 {
-  if (msg->property_status_code () != 200)
+  if (msg->property_status_code () != 200 &&
+      msg->property_status_code () != 302)
     {
       update_tags_failed.emit (item);
       return;
@@ -1340,7 +1346,7 @@ SessionConnector::on_add_document_attempted (Glib::RefPtr < Soup::Message >
 				    mem_fun (this,
 					     &SessionConnector::
 					     on_new_document_updated_tag),
-				    slot, document));
+				    slot, document), false);
     }
   else
     slot (document);
@@ -1529,7 +1535,7 @@ SessionConnector::modify_gallery (Gallery * gallery,
 					gallery->get_id ());
   Glib::RefPtr < Soup::Message > msg = Soup::Message::create ("GET", url);
   int status = web->send_message (msg);
-  if (status != 200)
+  if (status != 200 && status != 302)
     {
       modify_gallery_failed.emit (gallery);
       return;
@@ -1633,7 +1639,7 @@ SessionConnector::on_modify_gallery_attempted (Glib::RefPtr < Soup::Message >
 				    mem_fun (this,
 					     &SessionConnector::
 					     on_modify_gallery_updated_tag),
-				    slot, gallery));
+				    slot, gallery), true);
     }
   else
     slot (gallery);
@@ -1749,7 +1755,7 @@ SessionConnector::on_modify_document_attempted (Glib::RefPtr < Soup::Message >
 				    mem_fun (this,
 					     &SessionConnector::
 					     on_modify_document_updated_tag),
-				    slot, document));
+				    slot, document), false);
     }
   else
     slot (document);
@@ -2100,7 +2106,7 @@ std::list < std::string >
     {
       if (d[i] == " " || d[i] == "\n" || d[i] == "")
 	continue;
-      tags.push_back (d[i]);
+      tags.push_back (String::utrim(d[i]));
     }
   return tags;
 }
