@@ -58,7 +58,7 @@ TapiocaWindow::TapiocaWindow(BaseObjectType* baseObject,
 
   xml->get_widget("contents", contents);
 
-  set_icon_from_file(Main::get_data_path() + "/icon.png");
+  set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   std::list<Gtk::TargetEntry> targets;
   targets.push_back(Gtk::TargetEntry("TapiocaDocument", Gtk::TARGET_SAME_APP));
   targets.push_back(Gtk::TargetEntry("GTK_TREE_MODEL_ROW", Gtk::TARGET_SAME_WIDGET));
@@ -228,7 +228,7 @@ void TapiocaWindow::on_connect_clicked()
                            Gtk::MESSAGE_ERROR);
       e.set_modal();
       e.set_title("Warning!");
-      e.set_icon_from_file(Main::get_data_path() + "/icon.png");
+      e.set_icon_from_file(Main::get_data_path() + "/tapioca.png");
       e.run();
     }
 
@@ -265,7 +265,7 @@ void TapiocaWindow::on_pull_galleries_failed(Session *s, ProgressDialog &d)
                        Gtk::MESSAGE_ERROR);
   e.set_modal();
   e.set_title("Whoops!");
-  e.set_icon_from_file(Main::get_data_path() + "/icon.png");
+  e.set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   e.run();
 }
 
@@ -428,7 +428,7 @@ void TapiocaWindow::remove_deleted_documents()
       Gtk::MessageDialog d(removed, Gtk::MESSAGE_ERROR);
       d.set_modal();
       d.set_title("Some documents were not loaded");
-      d.set_icon_from_file(Main::get_data_path() + "/icon.png");
+      d.set_icon_from_file(Main::get_data_path() + "/tapioca.png");
       d.run();
     }
   update_window_title();
@@ -509,7 +509,8 @@ void TapiocaWindow::on_save_changes_to_atpic_clicked()
   if (response == Gtk::RESPONSE_ACCEPT)
     {
       session->revert(d->get_reverted_changes());
-      session->apply(d->get_changes());
+      SessionChanges changes = session->get_changes();
+      //session->apply(d->get_changes()); hmm, what is this for?
       if (d->get_reverted_changes().empty() == false ||
           d->get_changes().empty() == false)
         {
@@ -518,7 +519,6 @@ void TapiocaWindow::on_save_changes_to_atpic_clicked()
           update_menuitems();
         }
       d->hide();
-      SessionChanges changes = session->get_changes();
       if (changes.empty() == false)
         {
           PublishDialog *di = PublishDialog::create(changes);
@@ -533,8 +533,6 @@ void TapiocaWindow::on_save_changes_to_atpic_clicked()
                 (sigc::mem_fun(*this, &TapiocaWindow::on_progress_aborted));
               Glib::signal_idle().connect_once(sigc::bind<SessionChanges&, ProgressDialog&>(sigc::mem_fun(*this, &TapiocaWindow::publish), changes, pd));
               pd.run();
-              //publish(changes);
-              //publish these changes now.
             }
           delete di;
         }
@@ -789,13 +787,13 @@ void TapiocaWindow::on_about_clicked()
 
   xml->get_widget("dialog", dialog);
   dialog->set_transient_for(*this);
-  dialog->set_icon_from_file(Main::get_data_path() + "/icon.png");
+  dialog->set_icon_from_file(Main::get_data_path() + "/tapioca.png");
 
   std::string name = PACKAGE_NAME;
   std::transform(name.begin(), ++name.begin(), name.begin(), toupper);
   dialog->set_program_name(name);
   dialog->set_version(PACKAGE_VERSION);
-  dialog->set_logo(Gdk::Pixbuf::create_from_file(Main::get_data_path() + "/icon.png"));
+  dialog->set_logo(Gdk::Pixbuf::create_from_file(Main::get_data_path() + "/tapioca.png"));
   dialog->show_all();
   dialog->run();
   delete dialog;
@@ -1254,7 +1252,7 @@ void TapiocaWindow::update_window_title()
 void TapiocaWindow::view_document(Document *document)
 {
   if (document->is_local() == true)
-    view_downloaded_document(document, document->get_filename());
+    view_local_document(document, document->get_filename());
   else
     {
       //short circuit: did we already download it?
@@ -1309,7 +1307,7 @@ void TapiocaWindow::on_document_download_failed(Document *document, ProgressDial
                        Gtk::MESSAGE_ERROR);
   e.set_modal();
   e.set_title("Whoops!");
-  e.set_icon_from_file(Main::get_data_path() + "/icon.png");
+  e.set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   e.run();
 }
 
@@ -1320,7 +1318,7 @@ void TapiocaWindow::on_export_document_download_failed(Document *document, Progr
                        Gtk::MESSAGE_ERROR);
   e.set_modal();
   e.set_title("Whoops!");
-  e.set_icon_from_file(Main::get_data_path() + "/icon.png");
+  e.set_icon_from_file(Main::get_data_path() + "/tapioca.png");
   e.run();
 }
 
@@ -1445,6 +1443,23 @@ void TapiocaWindow::export_downloaded_document(Tapioca::Document *document, std:
   Glib::signal_idle().connect_once(sigc::bind<ProgressDialog&, std::string, std::list<Document*> >(sigc::mem_fun(*this, &TapiocaWindow::export_documents_in_the_background), d, export_dir, docs));
 }
 
+void TapiocaWindow::view_local_document(Tapioca::Document *document, std::string file)
+{
+  std::string prog;
+  Glib::RefPtr<Gnome::Conf::Client> conf_client;
+  conf_client = Gnome::Conf::Client::get_default_client();
+  if (Document::is_video_filename(file) == true)
+    prog = conf_client->get_string("/apps/" PACKAGE_NAME 
+                                   "/general/video_viewer_path");
+  else
+    prog = conf_client->get_string("/apps/" PACKAGE_NAME 
+                                   "/general/image_viewer_path");
+
+  std::string cmd = prog + " " + file;
+  if (file != "")
+    Glib::spawn_command_line_async(cmd);
+}
+
 void TapiocaWindow::view_downloaded_document(Tapioca::Document *document, std::string file)
 {
   if (progress_aborted)
@@ -1536,6 +1551,13 @@ void TapiocaWindow::on_pulled_documents_for_gallery(Gallery *gallery, std::list<
       thumbnail_urls.remove(url);
       s->pull_thumbnail(url, sigc::bind<Session*, std::list<std::string>, ProgressDialog& >(sigc::mem_fun(this, &TapiocaWindow::on_thumbnail_downloaded), s, thumbnail_urls, d));
         }
+      else
+        {
+          //here's the case where we have a gallery containing zero documents.
+          d.hide();
+          on_galleries_pulled(s);
+        }
+
       return;
     }
   Gallery *g = galleries.front();
@@ -1562,7 +1584,7 @@ void TapiocaWindow::add_published_galleries(sigc::slot<void> slot, ProgressDialo
 
 void TapiocaWindow::remove_published_galleries(sigc::slot<void> slot, ProgressDialog &d)
 {
-  if (publish_changes.removed_documents.size() == 0)
+  if (publish_changes.removed_galleries.size() == 0)
     {
       slot();
       return;
@@ -1739,11 +1761,13 @@ void TapiocaWindow::modify_published_galleries(sigc::slot<void> slot, ProgressDi
   Gallery *gallery = session->find_by_id
     (publish_changes.modified_galleries.front().first.get_id());
   if (gallery)
+    {
     session->modify_gallery
       (gallery, sigc::bind(sigc::mem_fun
                            (*this, 
                             &TapiocaWindow::on_published_gallery_modified), 
-                           slot, d));
+                            slot, d));
+    }
 }
 
 void TapiocaWindow::on_published_gallery_modified(Gallery *gallery, sigc::slot<void> slot, ProgressDialog &d)
@@ -1798,6 +1822,12 @@ void TapiocaWindow::on_published_document_modified(Document *document, sigc::slo
 void TapiocaWindow::on_published_documents_modified(ProgressDialog &d)
 {
   //and we're done with the giant chain of publishing phases.
+  //all done
+  //finished
+  session->get_profile()->remove_all_galleries();
+  session->get_profile()->add(session);
+  needs_saving = false;
+  update_window_title();
   d.hide();
 }
 
@@ -1887,7 +1917,8 @@ void TapiocaWindow::on_gallery_tags_changed(std::list<std::string> tags, Tapioca
       get_selected_document() == NULL)
     {
       on_tags_changed(tags);
-      item_tagging_widget->fill_tags(tags, session->get_tags());
+      if (item_tagging_widget)
+        item_tagging_widget->fill_tags(tags, session->get_tags());
     }
 }
 
@@ -1896,6 +1927,7 @@ void TapiocaWindow::on_document_tags_changed(std::list<std::string> tags, Tapioc
   if (document->get_id() == get_selected_document()->get_id())
     {
       on_tags_changed(tags);
-      item_tagging_widget->fill_tags(tags, session->get_tags());
+      if (item_tagging_widget)
+        item_tagging_widget->fill_tags(tags, session->get_tags());
     }
 }
